@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -7,6 +7,7 @@
 
 #include "checksum.h"
 #include "macros.h"
+#include "nethelp.h"
 
 //generate a checksum
 //also includes Pseudo1 and Pseudo2 in the checksum - set to 0x0000 for normal operation
@@ -25,7 +26,7 @@ unsigned short Checksum( unsigned char * pData, unsigned short Length, unsigned
 
   //add last byte
   if( Length >= 1 )
-    sum += *pData << 8;
+    sum += (unsigned short)(*pData << 8);
 
   //convert sum to one's complement sum 
   sum = (sum & 0x0000FFFF) + (sum >> 16); //add carries (bits 31..16) to sum (bits 15..0)
