@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -11,6 +11,7 @@
 #include "config.h"
 #include "eeprom.h"
 #include "macros.h"
+#include "output.h"
 #include "rtl8019.h"
 
 //convert 3 BCD digits to a byte
@@ -24,6 +25,25 @@ static inline unsigned char Code3Bcd2Byte( unsigned char * pCode, unsigned char
     return (pCode[Pos>>1] & 0x0F) * 100 + (pCode[(Pos>>1)+1] >> 4) * 10 + (pCode[(Pos>>1)+1] & 0x0F);
 }
 
+//convert 5 BCD digits to a word
+static inline unsigned short Code5Bcd2Word( unsigned char * pCode, unsigned char Pos )
+{
+  //word starts at even position
+  if( (Pos & 0x01) == 0x00 )
+    return (unsigned short)(pCode[Pos>>1] >> 4) * 10000
+         + (unsigned short)(pCode[Pos>>1] & 0x0F) * 1000
+         + (unsigned short)(pCode[(Pos>>1)+1] >> 4) * 100
+         + (unsigned short)(pCode[(Pos>>1)+1] & 0x0F) * 10
+         + (unsigned short)(pCode[(Pos>>1)+2] >> 4);
+  //word starts at odd position
+  else
+    return (unsigned short)(pCode[Pos>>1] & 0x0F) * 10000
+         + (unsigned short)(pCode[(Pos>>1)+1] >> 4) * 1000
+         + (unsigned short)(pCode[(Pos>>1)+1] & 0x0F) * 100
+         + (unsigned short)(pCode[(Pos>>1)+2] >> 4) * 10
+         + (unsigned short)(pCode[(Pos>>1)+2] & 0x0F);
+}
+
 //set MAC address
 //code is stored in BCD, MSB first - magic is already removed
 //returns 0x00 on success
@@ -157,10 +177,34 @@ static inline unsigned char CodeSetGw( unsigned char * pCode, unsigned char Code
   return 0x00;
 }
 
-//set symmetric key
+//set port for S8P
 //code is stored in BCD, MSB first - magic is already removed
 //returns 0x00 on success
-static inline unsigned char CodeSetKey( unsigned char * pCode, unsigned char CodeLen )
+static inline unsigned char CodeSetS8pPort( unsigned char * pCode, unsigned char CodeLen )
+{
+  unsigned short port;
+
+  //invalid length
+  if( CodeLen != 7 )
+    return 0xFF;
+  
+  //get port number from from code
+  port = Code5Bcd2Word( pCode, 2 );
+
+  //save port for S8P (atomically)
+  cli( );
+  ConfigS8pPort = port;
+  sei( );
+  //schedule write to EEPROM
+  EepromNeedWrite |= EepromNeedWriteS8pPort;
+
+  return 0x00;
+}
+
+//set symmetric key for S8P
+//code is stored in BCD, MSB first - magic is already removed
+//returns 0x00 on success
+static inline unsigned char CodeSetS8pKey( unsigned char * pCode, unsigned char CodeLen )
 {
   unsigned char key[16], i, j;
 
@@ -174,45 +218,86 @@ static inline unsigned char CodeSetKey( unsigned char * pCode, unsigned char Cod
 
   //set symmetric key (atomically)
   cli( );
-  for( i = 0; i < min( count( key ), count( ConfigKey ) ); i++ )
-    ConfigKey[i] = key[i];
+  for( i = 0; i < min( count( key ), count( ConfigS8pKey ) ); i++ )
+    ConfigS8pKey[i] = key[i];
   sei( );
   //schedule write to EEPROM
-  EepromNeedWrite |= EepromNeedWriteKey;
+  EepromNeedWrite |= EepromNeedWriteS8pKey;
 
   return 0x00;
 }
 
-//deactivate webserver
+//set port for webserver
 //code is stored in BCD, MSB first - magic is already removed
 //returns 0x00 on success
-static inline unsigned char CodeDeactWeb( unsigned char * pCode, unsigned char CodeLen )
+static inline unsigned char CodeSetWebPort( unsigned char * pCode, unsigned char CodeLen )
+{
+  unsigned short port;
+
+  //invalid length
+  if( CodeLen != 7 )
+    return 0xFF;
+  
+  //get port number from from code
+  port = Code5Bcd2Word( pCode, 2 );
+
+  //save port for webserver (atomically)
+  cli( );
+  ConfigWebPort = port;
+  sei( );
+  //schedule write to EEPROM
+  EepromNeedWrite |= EepromNeedWriteWebPort;
+
+  return 0x00;
+}
+
+//save default output state
+static inline unsigned char CodeSaveDefOut( unsigned char * pCode, unsigned char CodeLen )
 {
   //invalid length
   if( CodeLen != 2 )
     return 0xFF;
 
-  //deactivate webserver (atomically because only a single assignment)
-  ConfigWeb = 0x00;
+  //save default output state (atomically because only a single assignment)
+  ConfigDefOut = OutputGetState( );
   //schedule write to EEPROM
-  EepromNeedWrite |= EepromNeedWriteWeb;
+  EepromNeedWrite |= EepromNeedWriteDefOut;
 
   return 0x00;
 }
 
-//activate webserver
-//code is stored in BCD, MSB first - magic is already removed
-//returns 0x00 on success
-static inline unsigned char CodeActWeb( unsigned char * pCode, unsigned char CodeLen )
+//set default output state
+static inline unsigned char CodeSetDefOut( unsigned char * pCode, unsigned char CodeLen )
 {
+  unsigned char i, digit, defOut;
+
   //invalid length
-  if( CodeLen != 2 )
+  if( CodeLen != 10 )
     return 0xFF;
 
-  //activate webserver (atomically because only a single assignment)
-  ConfigWeb = 0x01;
+  //parse default output state into a single byte
+  //8 times "0" or "1"
+  defOut = 0;
+  for( i = 1; i < 5; i++ )
+  {
+    defOut >>= 1; //next digit
+    digit = pCode[i] >> 4; //1st digit in byte
+    if( digit != 0 && digit != 1 )
+      return 0xFF;
+    if( digit == 1 )
+      defOut |= 0x80;
+    defOut >>= 1; //next digit
+    digit = pCode[i] & 0x0F; //2nd digit in byte
+    if( digit != 0 && digit != 1 )
+      return 0xFF;
+    if( digit == 1 )
+      defOut |= 0x80;
+  }
+
+  //store default output state (atomically because only a single assignment)
+  ConfigDefOut = defOut;
   //schedule write to EEPROM
-  EepromNeedWrite |= EepromNeedWriteWeb;
+  EepromNeedWrite |= EepromNeedWriteDefOut;
 
   return 0x00;
 }
@@ -237,9 +322,11 @@ unsigned char CodeProc( unsigned char * pCode, unsigned char CodeLen )
     case 0x10: return CodeSetIp( pCode, CodeLen ); //set IP address
     case 0x11: return CodeSetMask( pCode, CodeLen ); //set subnet mask address
     case 0x12: return CodeSetGw( pCode, CodeLen ); //set gateway IP address
-    case 0x20: return CodeSetKey( pCode, CodeLen ); //set symmetric key
-    case 0x30: return CodeDeactWeb( pCode, CodeLen ); //deactivate webserver
-    case 0x31: return CodeActWeb( pCode, CodeLen ); //activate webserver
+    case 0x20: return CodeSetS8pPort( pCode, CodeLen ); //set port for S8P
+    case 0x21: return CodeSetS8pKey( pCode, CodeLen ); //set symmetric key for S8P
+    case 0x30: return CodeSetWebPort( pCode, CodeLen ); //set port for webserver
+    case 0x40: return CodeSaveDefOut( pCode, CodeLen ); //save default output state
+    case 0x41: return CodeSetDefOut( pCode, CodeLen ); //set default output state
   }
 
   //unknown code
