@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -8,9 +8,6 @@
 #ifndef INC_config
 #define INC_config
 
-//maximum receive and transmit unit
-#define CONFIG_MRU_MTU 768
-
 //MAC address
 extern unsigned char ConfigMac[6];
 
@@ -19,10 +16,16 @@ extern unsigned char ConfigIp[4]; //own IP address
 extern unsigned char ConfigMask[4]; //subnet mask
 extern unsigned char ConfigGw[4]; //gateway IP address
 
-//symmetric key
-extern unsigned char ConfigKey[16];
+//port for S8P
+extern unsigned short ConfigS8pPort; //disabled if 0
 
-//if webserver is enabled
-extern unsigned char ConfigWeb; //enabled if != 0x00
+//symmetric key for S8P
+extern unsigned char ConfigS8pKey[16];
+
+//port for webserver
+extern unsigned short ConfigWebPort; //disabled if 0
+
+//default output state
+extern unsigned char ConfigDefOut;
 
 #endif //#ifndef INC_config
