@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -11,6 +11,7 @@
 #include "config.h"
 #include "eeprom.h"
 #include "macros.h"
+#include "output.h"
 #include "rtl8019.h"
 
 //flags for what needs to be written to the EEPROM
@@ -31,9 +32,11 @@ unsigned char EepromWriteCnt; //number of bytes still to write
 #define EEPROM_ADDR_IP (EEPROM_ADDR_MAC + 2 * sizeof( ConfigMac ))
 #define EEPROM_ADDR_MASK (EEPROM_ADDR_IP + 2 * sizeof( ConfigIp ))
 #define EEPROM_ADDR_GW (EEPROM_ADDR_MASK + 2 * sizeof( ConfigMask ))
-#define EEPROM_ADDR_KEY (EEPROM_ADDR_GW + 2 * sizeof( ConfigGw ))
-#define EEPROM_ADDR_WEB (EEPROM_ADDR_KEY + 2 * sizeof( ConfigKey ))
-#define EEPROM_ADDR_FreeFromHere (EEPROM_ADDR_WEB + 2 * sizeof( ConfigWeb ))
+#define EEPROM_ADDR_S8P_PORT (EEPROM_ADDR_GW + 2 * sizeof( ConfigGw ))
+#define EEPROM_ADDR_S8P_KEY (EEPROM_ADDR_S8P_PORT + 2 * sizeof( ConfigS8pPort ))
+#define EEPROM_ADDR_WEB_PORT (EEPROM_ADDR_S8P_KEY + 2 * sizeof( ConfigS8pKey ))
+#define EEPROM_ADDR_DEF_OUT (EEPROM_ADDR_WEB_PORT + 2 * sizeof( ConfigWebPort ))
+#define EEPROM_ADDR_FreeFromHere (EEPROM_ADDR_DEF_OUT + 2 * sizeof( ConfigDefOut ))
 
 //get configuration from EEPROM - helper function
 //checks data in EEPROM
@@ -86,11 +89,19 @@ void EepromGetConfig( void ) //(extern)
   EepromGetConfigHelp( EEPROM_ADDR_MASK, ConfigMask, sizeof( ConfigMask ) );
   EepromGetConfigHelp( EEPROM_ADDR_GW, ConfigGw, sizeof( ConfigGw ) );
 
-  //get symmetric key
-  EepromGetConfigHelp( EEPROM_ADDR_KEY, ConfigKey, sizeof( ConfigKey ) );
+  //get port for S8P
+  EepromGetConfigHelp( EEPROM_ADDR_S8P_PORT, (unsigned char *)&ConfigS8pPort, sizeof( ConfigS8pPort ) );
 
-  //get if webserver is enabled
-  EepromGetConfigHelp( EEPROM_ADDR_WEB, &ConfigWeb, sizeof( ConfigWeb ) );
+  //get symmetric key for S8P
+  EepromGetConfigHelp( EEPROM_ADDR_S8P_KEY, ConfigS8pKey, sizeof( ConfigS8pKey ) );
+
+  //get port for webserver
+  EepromGetConfigHelp( EEPROM_ADDR_WEB_PORT, (unsigned char *)&ConfigWebPort, sizeof( ConfigWebPort ) );
+
+  //get default output state
+  if( EepromGetConfigHelp( EEPROM_ADDR_DEF_OUT, &ConfigDefOut, sizeof( ConfigDefOut ) ) == 0x00 )
+    //set output to default state
+    OutputSetState( ConfigDefOut );
 }
 
 //task function to do the work - call from main loop
@@ -135,22 +146,40 @@ void EepromTask( void ) //(extern)
       EepromWriteCnt = sizeof( ConfigGw );
       EepromWriteFlags = EepromWriteFlagActive;
     }
-    //symmetric key needs to be written
-    else if( EepromNeedWrite & EepromNeedWriteKey )
+    //port for S8P needs to be written
+    else if( EepromNeedWrite & EepromNeedWriteS8pPort )
     {
-      EepromNeedWrite &= ~EepromNeedWriteKey;
-      pEepromWriteSrc = ConfigKey;
-      EepromWriteDestAddr = EEPROM_ADDR_KEY;
-      EepromWriteCnt = sizeof( ConfigKey );
+      EepromNeedWrite &= ~EepromNeedWriteS8pPort;
+      pEepromWriteSrc = (unsigned char *)&ConfigS8pPort;
+      EepromWriteDestAddr = EEPROM_ADDR_S8P_PORT;
+      EepromWriteCnt = sizeof( ConfigS8pPort );
       EepromWriteFlags = EepromWriteFlagActive;
     }
-    //if webserver is enabled needs to be written
-    else if( EepromNeedWrite & EepromNeedWriteWeb )
+    //symmetric key for S8P needs to be written
+    else if( EepromNeedWrite & EepromNeedWriteS8pKey )
     {
-      EepromNeedWrite &= ~EepromNeedWriteWeb;
-      pEepromWriteSrc = &ConfigWeb;
-      EepromWriteDestAddr = EEPROM_ADDR_WEB;
-      EepromWriteCnt = sizeof( ConfigWeb );
+      EepromNeedWrite &= ~EepromNeedWriteS8pKey;
+      pEepromWriteSrc = ConfigS8pKey;
+      EepromWriteDestAddr = EEPROM_ADDR_S8P_KEY;
+      EepromWriteCnt = sizeof( ConfigS8pKey );
+      EepromWriteFlags = EepromWriteFlagActive;
+    }
+    //port for webserver needs to be written
+    else if( EepromNeedWrite & EepromNeedWriteWebPort )
+    {
+      EepromNeedWrite &= ~EepromNeedWriteWebPort;
+      pEepromWriteSrc = (unsigned char *)&ConfigWebPort;
+      EepromWriteDestAddr = EEPROM_ADDR_WEB_PORT;
+      EepromWriteCnt = sizeof( ConfigWebPort );
+      EepromWriteFlags = EepromWriteFlagActive;
+    }
+    //if default output state needs to be written
+    else if( EepromNeedWrite & EepromNeedWriteDefOut )
+    {
+      EepromNeedWrite &= ~EepromNeedWriteDefOut;
+      pEepromWriteSrc = &ConfigDefOut;
+      EepromWriteDestAddr = EEPROM_ADDR_DEF_OUT;
+      EepromWriteCnt = sizeof( ConfigDefOut );
       EepromWriteFlags = EepromWriteFlagActive;
     }
     //nothing needs to be written
