@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -13,8 +13,10 @@
 #define EepromNeedWriteIp 0x02
 #define EepromNeedWriteMask 0x04
 #define EepromNeedWriteGw 0x08
-#define EepromNeedWriteKey 0x10
-#define EepromNeedWriteWeb 0x20
+#define EepromNeedWriteS8pPort 0x10
+#define EepromNeedWriteS8pKey 0x20
+#define EepromNeedWriteWebPort 0x40
+#define EepromNeedWriteDefOut 0x80
 extern unsigned char EepromNeedWrite;
 
 //get configuration from EEPROM
