@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -10,6 +10,7 @@
 #include "ethernet.h"
 #include "ip.h"
 #include "macros.h"
+#include "nethelp.h"
 #include "rtl8019.h"
 
 //process a received ethernet packet
