@@ -1,15 +1,17 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
  */
 
 #include <avr/io.h>
+#include <avr/interrupt.h>
 
 #include "code.h"
 #include "keypad.h"
 #include "macros.h"
+#include "output.h"
 #include "random.h"
 #include "timing.h"
 
@@ -204,12 +206,14 @@ void KeypadTask( void ) //(extern)
   if( KeypadCodeLen >> 1 > count( KeypadCode ) )
   {
     //if a key is pressed - toggle output
-    for( mask = KEYPAD_MASK_1; mask != KEYPAD_MASK_9; mask <<= 1 )
+    for( i = 1, mask = KEYPAD_MASK_1; i <= 8; i++, mask <<= 1 )
     {
       if( KeypadPressed & mask )
       {
         KeypadPressed &= ~mask;
-        PORTD ^= mask >> 1;
+        cli( );
+        OutputChange( -1, i ); //toggle output
+        sei( );
       }
     }
     //ignore keys 0 and 9
