@@ -1,34 +1,42 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
  */
 
-#include <avr/io.h>
 #include <avr/interrupt.h>
+#include <avr/wdt.h>
 
 #include "arp.h"
 #include "eeprom.h"
+#include "http.h"
 #include "keypad.h"
+#include "output.h"
 #include "rtl8019.h"
+#include "s8p.h"
+#include "tcp.h"
 #include "timing.h"
 #include "uart.h"
 
 //main code entry point
 int main( void )
 {
-  //initialize output port
-  DDRD = 0xFF;
-  PORTD = 0x00;
-  
+  wdt_reset( );
+  wdt_enable( WDTO_60MS );
+  wdt_reset( );
+
   //initialize uart to be able to use stdio
   UartInit( );
 
   //initialize modules
   ArpInit( );
+  HttpInit( );
   KeypadInit( );
+  OutputInit( );
   RtlInit( );
+  S8pInit( );
+  TcpInit( );
   TimingInit( );
 
   //get configuration from EEPROM
@@ -40,8 +48,10 @@ int main( void )
   //main loop
   while( 1 )
   {
+    wdt_reset( );
     EepromTask( );
     KeypadTask( );
+    S8pTask( );
   }
 
   return 0;
