@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -8,6 +8,7 @@
 #include <avr/io.h>
 #include <avr/interrupt.h>
 #include <avr/signal.h>
+#include <avr/wdt.h>
 
 #include "config.h"
 #include "ethernet.h"
@@ -17,7 +18,11 @@
 #include "timing.h"
 
 //maximum receive unit
-#define RTL_MRU CONFIG_MRU_MTU
+#define RTL_MRU 640
+
+//reinitialization timeout
+// - if no reception is detected for this time, the RTL8019 is reinitialized
+#define RtlReinitTimeoutTicks 50 //in 200ms steps
 
 //IO pins of RTL8019
 #define RTL_ADDR_DDR DDRC
@@ -119,6 +124,9 @@
           RTL_READ_IDLE( ); /* take back read signal */ \
         }
 
+//reinitialization timeout counter
+volatile unsigned char RtlReinitTimeout = 0;
+
 //initialize
 void RtlInit( void ) //(extern)
 {
@@ -194,6 +202,22 @@ void RtlReinit( void ) //(extern)
 
   //start RTL8019
   RTL_WRITE( RTL_REG_CR, 1<<RTL_CR_STA | 1<<RTL_CR_RD2 );
+
+  //clear reinitialization timeout
+  RtlReinitTimeout = 0;
+}
+
+//tick procedure - call every 200ms from timer interrupt
+//must be called with interrupts disabled
+void RtlTick200( void ) //(extern)
+{
+  //increment reinitialization timeout counter
+  RtlReinitTimeout++;
+
+  //reinitialization timeout
+  if( RtlReinitTimeout >= RtlReinitTimeoutTicks )
+    //reinitialize RTL8019 (resets reinitialization timeout)
+    RtlReinit( );
 }
 
 //write an ethernet frame to the RTL8019
@@ -291,6 +315,10 @@ static inline void RtlRecv( void )
   PacketLen = count( Packet );
   RtlReadFrame( Packet, &PacketLen );
 
+  //this is not very good in interrupt
+  // - but what else shall we do in case of heavy network load?
+  wdt_reset( );
+
   //pass packet on to ethernet
   EthernetRecv( Packet, PacketLen );
 }
@@ -334,5 +362,8 @@ SIGNAL( SIG_INTERRUPT4 )
 
   //start RTL8019
   RTL_WRITE( RTL_REG_CR, 1<<RTL_CR_STA | 1<<RTL_CR_RD2 );
+
+  //clear reinitialization timeout
+  RtlReinitTimeout = 0;
 }
 
