@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -15,6 +15,10 @@ extern void RtlInit( void );
 //must be called with interrupts disabled
 extern void RtlReinit( void );
 
+//tick procedure - call every 200ms from timer interrupt
+//must be called with interrupts disabled
+extern void RtlTick200( void );
+
 //write an ethernet frame to the RTL8019
 //must be called with interrupts disabled
 extern void RtlWriteFrame( char * pData, unsigned short Length );
