@@ -1,5 +1,5 @@
 /* 8BitAmEthernet
- * version 0.1 date 2005-02-21
+ * version 0.2.1 date 2005-03-08
  * Copyright 2005 Stefan Schuermans <1stein@schuermans.info>
  * Copyleft: GNU public license - http://www.gnu.org/copyleft/gpl.html
  * a project of CCC-AC - http://www.cccac.de/
@@ -12,6 +12,8 @@
 #include "arp.h"
 #include "ip.h"
 #include "keypad.h"
+#include "rtl8019.h"
+#include "tcp.h"
 #include "timing.h"
 #include "udp.h"
 
@@ -33,13 +35,16 @@ SIGNAL( SIG_OUTPUT_COMPARE0 )
   //generate 200ms steps
   Timing2_100++;
   if( Timing2_100 >= 100 )
-  {
     Timing2_100 = 0;
 
-    //call 200ms tick functions
-    ArpTick200( );
-    IpTick200( );
-    UdpTick200( );
+  //call 200ms tick functions at different times
+  switch( Timing2_100 )
+  {
+    case 10: ArpTick200( ); break;
+    case 30: IpTick200( ); break;
+    case 50: RtlTick200( ); break;
+    case 70: TcpTick200( ); break;
+    case 90: UdpTick200( ); break;
   }
 }
 
